function [B]=Effektiv(r,xn,yn,z,Fi,I0,d0,f)
% function [B]=Effektiv(r,xn,yn,z,Fi,I0,d0,f)
% Datei Efektiv.m
% Berechnet den Effektivwert der magn. Flussdichte eines Dreileiter-
%   Drehstromsystems mittels Integration des Betrags des resultierenden 
%   Feldvektors ber eine Periode (Trapezregel)
% Der Nulleiter wird in diesem Modell nicht bercksichtigt
% Die unterschiedliche r-Abhngigkeit des Magnetfeldes innerhalb und 
%   auerhalb eines Leiters wird bercksichtigt.
% Die Matlab Warnung "Division durch Null" wird unterdrckt!!!!!
%
% Eingabeparameter:  
%           r   Ortsvektor des Messpunktes (m) (3 Komponenten)
%           xn  Vektor mit den x-Koordinaten (m)der 3 Leiter (3 Komp.)                               
%           yn  Vektor mit den y-Koordinaten (m)der 3 Leiter (3 Komp.)                            
%           z   Vektor mit den z-Koordinaten der Leiterendpunkte (2 Komp.) 
%                      z(1)=unteres Ende (m)
%                      z(2)=oberes Ende  (m)
%           Fi  Vektor der 3 Phasenwinkel (Grad) (3 Komp.) 
%           I0  Vektor der 3 Stromstrken (A) (3 Komp.) 
%           d0  Leiterdurchmesser (m) 
%           f   Frequenz des Stroms (Hz)
%  Ausgabeparameter: 
%           BCos Effektivwert der Flussdichte in Tesla Kosinusstrom 
%           BSin Effektivwert der Flussdichte in Tesla Sinusstrom
% Autor Hans J. Wagner 21. April 2005
% 18. 10. 2006: erweitert um Feldabhngigkeit innerhalb eines Leiters
%               schnellere Integration durch Ausnutzung der Symmetrie (5
%               Punkte gengen)
% 19. 2. 2007:  variable x-Koordinaten fr die Leiter eingefhrt
% 14. 10. 2007 Tippfehler korrigiert

warning off MATLAB:divideByZero % Schaltet diese Warnmeldung ab
w=2*pi*f; %Kreisfrequenz
Fi=Fi*pi/180; %Phasenwinkel im Bogenmass
t=linspace(0,1/f,5); % Zeitvariable zur Integration ber eine Periode (s)
for k = 1: length(xn); 
    vektor=[r(1)-xn(k),r(2)-yn(k)];  % Ortsvektor vom Leiter zum Messpunkt
    betrag=sqrt(vektor(1)^2+vektor(2)^2); % Betrag des Otsvektors
    if betrag < d0/2    % Messpunkt liegt innerhalb des Leiters
    I0(k)=I0(k)*(2*betrag/d0)^2; % wirksamen Stromanteil berechnen
    end;
end;
% Initialisierung der Ergebnisvektoren beschleunigt Rechnung
FeldBetrag=zeros(size(t)); 
for k = 1: length(t); % Schleife zur Berechnung
    I = [I0(1)*exp(j*(t(k)*w-Fi(1)))
        I0(2)*exp(j*(t(k)*w-Fi(2)))
        I0(3)*exp(j*(t(k)*w-Fi(3)))];
    Feld1=Fmagfeld(r,xn(1),yn(1),z,I(1)); % Feld Phase 1
    Feld2=Fmagfeld(r,xn(2),yn(2),z,I(2)); % Feld Phase 2
    Feld3=Fmagfeld(r,xn(3),yn(3),z,I(3)); % Feld Phase 3
    ResFeld = (Feld1+Feld2+Feld3)*4*pi*10^(-7); % Gesamtfluss in T(komplex)
    %FeldBetrag(k) = sqrt(sum(real(Mfeld).^2));%Betrag des Realteils von B
    FeldBetrag(k) = sqrt(sum(imag(ResFeld).^2));%Betrag des Imaginrteils 
end;
B = sqrt( trapz(t,FeldBetrag.^2)*f); % Berechnung des Effektivwertes
%
warning on MATLAB:divideByZero  % Schaltet Warnmeldung wieder ein
%================= Interne Funktion frs Magnetfeld  ====================
function [H]=Fmagfeld(r,xn,yn,z,I)
% Berechnung des bestimmten Integrals
og=(z(2)-r(3))/sqrt((r(1)-xn)^2+(r(2)-yn)^2+(r(3)-z(2))^2); % obere Grenze
ug=(z(1)-r(3))/sqrt((r(1)-xn)^2+(r(2)-yn)^2+(r(3)-z(1))^2); % untere Grenze
% Magnetfeld
H=I*[-r(2)+yn, r(1)-xn,0]/(4*pi*((r(1)-xn)^2+(r(2)-yn)^2))*(og-ug); 
%====================================================================

           
    